@@ -1,13 +1,17 @@
 #![doc(html_logo_url = "https://avatars.githubusercontent.com/u/54848194?v=4")]
+#![feature(doc_auto_cfg)]
 
 //! # BTW I USE ARCH
 //!
 //! Hello world!
 
 // Globals are declared outside all other scopes.
+#[cfg(feature = "arch")]
 pub static LANGUAGE: &str = "Rust";
+#[cfg(feature = "arch")]
 pub const THRESHOLD: i32 = 10;
 
+#[cfg(feature = "arch")]
 pub type Tuple0_0 = ();
 pub type Int8 = i8;
 
@@ -22,6 +26,7 @@ pub fn array_length(array: &[u8]) -> usize {
     array.len()
 }
 
+#[cfg(feature = "archlinux")]
 pub enum Devices {
     Pixelbook,
     Pixel5,
@@ -51,12 +56,13 @@ pub mod BTW {
 
 pub mod title;
 
-#[cfg(feature = "arch")]
+#[cfg(feature = "archlinux")]
 pub mod how_to_install_archlinux;
 
 pub mod Español {}
 pub mod 日本語 {}
 
+#[cfg(feature = "arch")]
 pub use BTW::I::USE::ARCH::*;
 
 pub trait Empty {}
@@ -69,6 +75,7 @@ impl<T: Empty> Any for T {}
 
 pub trait GitHub {}
 
+#[cfg(feature = "arch")]
 pub trait Linux {}
 
 pub trait Windows {}
